==> 0.2.0.tar.gz: lib/pages/home/slock/password/PasswordList.dart <==
import 'package:flutter/material.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_manage/pages/home/slock/password/AddPassword.dart';
import 'package:witsystem_device_manage/pages/home/slock/password/PasswordInfo.dart';
import 'package:witsystem_device_manage/pages/widget/CustomFloatingActionButtonLocation.dart';
import 'package:witsystem_device_manage/pages/widget/FloatingActionButtonScaffold.dart';
import 'package:witsystem_device_manage/util/DeviceInfoAuth.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';

///密码列表

class PasswordList extends StatefulWidget {
  final String deviceName;
  final String deviceId;

  const PasswordList(
      {Key? key, required this.deviceName, required this.deviceId})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _PasswordListState();
  }
}

class _PasswordListState extends State<PasswordList> {
  List list = [];

  @override
  void initState() {
    super.initState();
    initData();
  }

  initData() async {
    Map<String, dynamic>? device = await DeviceManage().device(widget.deviceId);
    print("获得的设备数据${device!["device"]["devicesSlock"]}");
    list.clear();
    if (device["device"]["devicesSlock"] == null) {
      setState(() {});
      return;
    }
    List deviceList = device["device"]["devicesSlock"];
    var length = deviceList.length;
    for (int i = length - 1; i >= 0; i--) {
      if (deviceList[i]["type"] == "PASSWORD") {
        deviceList[i]["dataType"] =
            DeviceInfoAuth.passwordAuthToString(deviceList[i]["dataType"]);
        list.add(deviceList[i]);
      }
    }

    setState(() {});
  }

  ///刷新
  refurbishDevice() async {
    await DeviceManage().refurbishDevice(widget.deviceId);
    await initData();
  }

  ///跳转到添加页面
  _toAddPage() {
    Navigator.of(context).push<bool>(MaterialPageRoute(builder: (context) {
      return AddPasswordWidget(
          deviceId: widget.deviceId, deviceName: widget.deviceName);
    })).then((bool? value) {
      if (value != null && value) {
        list.isEmpty //判断当前一个数据都没有的时候，延迟300毫秒在执行，是为空展示添加按键的收回动画
            ? Future.delayed(const Duration(milliseconds: 300), () {
                initData();
              })
            : initData();
      }
    });
  }


  @override
  Widget build(BuildContext context) {
    return FloatingActionButtonScaffold(
      title: S.of(context).device_passwordManage + "(${widget.deviceName})",
      centerHint: S.of(context).device_addPassword,
      floatingButtonOnTap: _toAddPage,
      crossFadeState:
          list.isEmpty ? CrossFadeState.showFirst : CrossFadeState.showSecond,
      body: SizedBox(
        height: double.infinity,
        width: double.infinity,
        child: RefreshIndicator(
            onRefresh: () async {
              await refurbishDevice();
              return Future.value(null);
            },
            child: ListView.builder(
                itemCount: list.length,
                itemBuilder: (context, index) {
                  return Flex(
                    direction: Axis.vertical,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      ListTile(
                        onTap: () {
                          Navigator.of(context)
                              .push<bool>(MaterialPageRoute(builder: (context) {
                            return PasswordInfoWidget(
                                deviceName: widget.deviceName,
                                deviceId: widget.deviceId,
                                passwordInfo: list[index]);
                          })).then((bool? value) {
                            if (value != null && value)
                              initData(); //判断返回true 代表需要更新页面信息
                          });
                        },
                        contentPadding: const EdgeInsets.all(5),
                        style: ListTileStyle.list,
                        leading: const CircleAvatar(
                          // backgroundImage: NetworkImage("https://witsystem.top/user/find_title_img?fileName="),
                          // backgroundImage: NetworkImage(
                          //     "https://img2.baidu.com/it/u=343850545,2320437498&fm=253&fmt=auto&app=138&f=JPEG?w=500&h=500"),
                          child: Icon(Icons.password),
                        ),
                        title: Text(list[index]["name"]),
                        subtitle: Text(list[index]["freeze"]
                            ? S.of(context).device_freeze
                            : S.of(context).device_normal),
                        trailing: Flex(
                          mainAxisSize: MainAxisSize.min,
                          direction: Axis.horizontal,
                          children: [
                            Text(
                              list[index]["dataType"],
                              style: TextStyle(
                                  color: Theme.of(context).primaryColor),
                            ),
                            const Icon(Icons.keyboard_arrow_right)
                          ],
                        ),
                      ),
                      const Divider()
                    ],
                  );
                })),
      ),
    );
  }
}

==> 0.2.8.tar.gz: lib/pages/home/slock/password/PasswordList.dart <==
import 'package:flutter/material.dart';
import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:witsystem_device_manage/pages/home/slock/password/AddPassword.dart';
import 'package:witsystem_device_manage/pages/home/slock/password/PasswordInfo.dart';
import 'package:witsystem_device_manage/pages/widget/FloatingActionButtonScaffold.dart';
import 'package:witsystem_device_manage/util/DeviceInfoAuth.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';

///密码列表

class PasswordList extends StatefulWidget {
  final String deviceId;

  const PasswordList({Key? key, required this.deviceId}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _PasswordListState();
  }
}

class _PasswordListState extends State<PasswordList> {
  List list = [];

  String deviceName = "";

  @override
  void initState() {
    super.initState();
    initData();
  }

  initData() async {
    Map<String, dynamic>? device = await DeviceManage().device(widget.deviceId);
    deviceName = device!["deviceName"];
    list.clear();
    if (device["device"]["devicesSlock"] == null) {
      setState(() {});
      return;
    }
    List deviceList = device["device"]["devicesSlock"];
    var length = deviceList.length;
    for (int i = length - 1; i >= 0; i--) {
      if (deviceList[i]["type"] == "PASSWORD") {
        deviceList[i]["dataType"] =
            DeviceInfoAuth.passwordAuthToString(deviceList[i]["dataType"]);
        list.add(deviceList[i]);
      }
    }

    setState(() {});
  }

  ///刷新
  refurbishDevice() async {
    await DeviceManage().refurbishDevice(widget.deviceId);
    await initData();
  }

  ///跳转到添加页面
  _toAddPage() {
    Navigator.of(context).push<bool>(MaterialPageRoute(builder: (context) {
      return AddPasswordWidget(
          deviceId: widget.deviceId, deviceName: deviceName);
    })).then((bool? value) {
      if (value != null && value) {
        list.isEmpty //判断当前一个数据都没有的时候，延迟300毫秒在执行，是为空展示添加按键的收回动画
            ? Future.delayed(const Duration(milliseconds: 300), () {
                initData();
              })
            : initData();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return FloatingActionButtonScaffold(
      title: S.of(context).device_passwordManage + "($deviceName)",
      centerHint: S.of(context).device_addPassword,
      floatingButtonOnTap: _toAddPage,
      crossFadeState:
          list.isEmpty ? CrossFadeState.showFirst : CrossFadeState.showSecond,
      body: SizedBox(
        height: double.infinity,
        width: double.infinity,
        child: RefreshIndicator(
            onRefresh: () async {
              await refurbishDevice();
              return Future.value(null);
            },
            child: ListView.builder(
                itemCount: list.length,
                itemBuilder: (context, index) {
                  return Flex(
                    direction: Axis.vertical,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      ListTile(
                        onTap: () {
                          Navigator.of(context)
                              .push<bool>(MaterialPageRoute(builder: (context) {
                            return PasswordInfoWidget(
                                deviceName: deviceName,
                                deviceId: widget.deviceId,
                                passwordInfo: list[index]);
                          })).then((bool? value) {
                            if (value != null && value)
                              initData(); //判断返回true 代表需要更新页面信息
                          });
                        },
                        contentPadding: const EdgeInsets.all(5),
                        style: ListTileStyle.list,
                        leading: const CircleAvatar(
                          // backgroundImage: NetworkImage("https://witsystem.top/user/find_title_img?fileName="),
                          // backgroundImage: NetworkImage(
                          //     "https://img2.baidu.com/it/u=343850545,2320437498&fm=253&fmt=auto&app=138&f=JPEG?w=500&h=500"),
                          child: Icon(Icons.password),
                        ),
                        title: Text(list[index]["name"]),
                        subtitle: Text(list[index]["freeze"]
                            ? S.of(context).device_freeze
                            : S.of(context).device_normal),
                        trailing: Flex(
                          mainAxisSize: MainAxisSize.min,
                          direction: Axis.horizontal,
                          children: [
                            Text(
                              list[index]["dataType"],
                              style: TextStyle(
                                  color: Theme.of(context).primaryColor),
                            ),
                            const Icon(Icons.keyboard_arrow_right)
                          ],
                        ),
                      ),
                      const Divider()
                    ],
                  );
                })),
      ),
    );
  }
}
